@@ -2,21 +2,12 @@ import asyncio,httpx,logging,json
 from .utils import *
 from abstract_apis import get_headers,get_response,get_async_response
 
-def get_response(obj):
-    try:
-        return obj.json()
-    except:
-        try:
-            return obj.text
-        except:
-
-            return obj
 def safe_json_dumps(obj):
     if isinstance(obj, dict):
         obj = json.dumps(obj)
     return obj
 
-async def make_request(url, payload, headers=None):
+async def async_make_request(url, payload, headers=None):
     async with httpx.AsyncClient(timeout=1000) as client:
         response = await client.post(url, data=safe_json_dumps(payload), headers=headers)
         response.raise_for_status()  # Raise exception for non-2xx status codes
@@ -81,31 +72,29 @@ def runSolcatcherSettings(response, solcatcherSettings):
         if 'getStatusCode' in solcatcherSettings and solcatcherSettings.get('getStatusCode') != False:
             response = {"result": response, "status_code": status_code}
     return response
-
-async def async_call_solcatcher_ts(endpoint, *args, **kwargs):
+def process_settings(*args, **kwargs):
+    kwargs["solcatcherSettings"] = kwargs.get("solcatcherSettings") or {"getResponse":True,"getResult":True}
     kwargs, solcatcherSettings, headers, bools = get_solcatcherSettings(**kwargs)
     payload = get_payload(*args, **kwargs)
+    return kwargs, solcatcherSettings, headers, bools, payload
+async def async_call_solcatcher_ts(endpoint, *args, **kwargs):
+    kwargs, solcatcherSettings, headers, bools, payload = process_settings(*args, **kwargs)
     url = getSolcatcherTsUrl(endpoint=endpoint)
-    response = await make_request(url, payload, headers=headers)
+    response = await async_make_request(url, payload, headers=headers)
     result = runSolcatcherSettings(response, solcatcherSettings)
     return result
 
 async def async_call_solcatcher_py(endpoint, *args, **kwargs):
-    kwargs["solcatcherSettings"] = kwargs.get("solcatcherSettings") or {"getResponse":True,"getResult":True}
-    kwargs, solcatcherSettings, headers, bools = get_solcatcherSettings(**kwargs)
-    payload = get_payload(*args, **kwargs)
+    kwargs, solcatcherSettings, headers, bools, payload = process_settings(*args, **kwargs)
     url = getSolcatcherPairCatchUrl(endpoint=endpoint)
-    response = await make_request(url, payload, headers=headers)
+    response = await async_make_request(url, payload, headers=headers)
     result = runSolcatcherSettings(response, solcatcherSettings)
     return result
 
 async def async_call_solcatcher_db(endpoint, *args, **kwargs):
-    
-    kwargs["solcatcherSettings"] = kwargs.get("solcatcherSettings") or {"getResponse":True,"getResult":True}
-    kwargs, solcatcherSettings, headers, bools = get_solcatcherSettings(True, **kwargs)
-    payload = get_payload(*args, **kwargs)
+    kwargs, solcatcherSettings, headers, bools, payload = process_settings(*args, **kwargs)
     url = getSolcatcherDbCalls(endpoint=endpoint)
-    response = await make_request(url, payload, headers=headers)
+    response = await async_make_request(url, payload, headers=headers)
     result = runSolcatcherSettings(response, solcatcherSettings)
     return result
 
@@ -130,7 +119,7 @@ async def async_call_rate_limiter(method, params=None, url_1_only=None, url_2_on
         logging.error(f"Error fetching {method}: {e}")
         return []
 
-async def async_make_rate_limited_call(method, params, url_1_only=True, url_2_only=False,**kwargs):
+async def async_make_rate_limited_call(method, params, url_1_only=True, url_2_only=False,*args,**kwargs):
     """
     Attempt up to 3 times. After the 2nd attempt, set url_2_only=True.
     After the 1st attempt, set url_1_only=False.
@@ -177,12 +166,19 @@ async def async_make_rate_limited_call(method, params, url_1_only=True, url_2_on
             return result
     # If no response after all attempts, return empty or raise an exception
     return []
+def make_request(url=None, payload={}, headers=None, url_1_only=None, url_2_only=False,*args, **kwargs):
+    if url == None:
+        if (url_1_only == None and url_2_only==None) or (url_1_only and not url_2_only):
+            url = solana_rpc_url
+        elif (not url_1_only and url_2_only) or (url_1_only and url_2_only):
+            url = fall_back_rpc
+    url = url or solana_rpc_url
+    return get_async_response(async_make_reques,url=url,payload=payload,headers=headers or get_headers())
+def call_rate_limiter(method, params, url_1_only=True, url_2_only=False,*args, **kwargs):
+    return get_async_response(async_call_rate_limiter,method=method, params=params, url_1_only=url_1_only, url_2_only=url_2_only,*args, **kwargs)
 
-def call_rate_limiter(method, params, url_1_only=True, url_2_only=False, **kwargs):
-    return get_async_response(async_call_rate_limiter,method=method, params=params, url_1_only=url_1_only, url_2_only=url_2_only, **kwargs)
-
-def make_rate_limited_call(method, params, url_1_only=True, url_2_only=False, **kwargs):
-    return get_async_response(async_make_rate_limited_call(method=method, params=params, url_1_only=url_1_only, url_2_only=url_2_only, **kwargs))
+def make_rate_limited_call(method, params, url_1_only=True, url_2_only=False,*args, **kwargs):
+    return get_async_response(async_make_rate_limited_call(method=method, params=params, url_1_only=url_1_only, url_2_only=url_2_only,*args, **kwargs))
 
 def call_solcatcher_py(endpoint, *args, **kwargs):
     return get_async_response(async_call_solcatcher_py,endpoint, *args, **kwargs)
