@@ -1,16 +1,10 @@
 import json
-from abstract_utilities import eatAll
+from abstract_utilities import eatAll,get_any_value
 from abstract_security import get_env_value
 from abstract_apis import get_headers,get_response
-import requests,asyncio
-async def call_async_function(func, *args, **kwargs):
-    """Helper function to call async functions in sync or async contexts."""
-    if asyncio.get_event_loop().is_running():
-        # If an event loop is already running, use await
-        return await func(*args, **kwargs)
-    else:
-        # If no event loop is running, use asyncio.run()
-        return await asyncio.run(func(*args, **kwargs))
+import requests
+solana_rpc_url="http://api.mainnet-beta.solana.com"
+fall_back_rpc = get_env_value('solana_fallback_rpc_url')
 def getSolcatcherUrl(endpoint=None):
   return getEndpointUrl(endpoint=endpoint,url='https://solcatcher.io')
 def getSolcatcherPairCatchUrl(endpoint=None):
@@ -19,14 +13,30 @@ def getSolcatcherTsUrl(endpoint=None):
   return getEndpointUrl(endpoint=endpoint,url='https://solcatcher.io/ts')
 def getSolcatcherDbCalls(endpoint=None):
   return getEndpointUrl(endpoint=endpoint,url="https://solcatcher.io/dbCalls")
+def get_response(response):
+    if isinstance(response,requests.Response):
+        try:
+            response = response.json()
+        except:
+          try:
+            response = response.text
+          except:
+            pass
+    return response
+def get_result(response,key='result'):
+    response = get_response(response)
+    if isinstance(response,dict):
+        result = get_any_value(response,key)
+        return result
+    return response
+def get_socatcherSettings(getResult = None,getResponse=None):
+    return {"getResult":getResult or True,"getResponse":getResponse or True}
 def get_db_header(headers=None, api_key=None):
     # Start with existing or default headers
     header = {}
-
     # Retrieve the key from environment or config
     key = api_key or get_env_value('SOLCATCHER_DB_API_KEY')
        # If key is not None, add the header; otherwise skip it
-    
     if key:
         header["X-API-KEY"] = str(key) if key else ""
     # else do not set "X-API-KEY" at all
@@ -77,3 +87,4 @@ def get_payload(*args,**kwargs):
     else:
         payload = kwargs
     return payload
+defaultSolcatcherSettings = get_socatcherSettings()
